@@ -12,7 +12,7 @@ from cognite.airworkflow.model.project import ProjectInfo
 
 class DeploySchedule:
     def __init__(self, project: str, path: Path, config: Config):
-        self.info: ProjectInfo = const.PROJECTS_TO_API_KEYS[project]
+        self.info: ProjectInfo = const.AUTHENTICATION[project]
         self.schedule: Schedule = config.schedule
         self.client: CogniteClient = cdf.experimental_client(self.info.project)
         self.model_name: str = path.parts[-1]
