@@ -22,7 +22,7 @@ class ModelAssetHierarchy:
         self.config = config
         self.airInfra = airInfra
         project_info = const.AUTHENTICATION[project]
-        print("Project: " + project_info.name)
+        print("Project: " + project_info.name, flush=True)
         self.client = cdf.experimental_client(project)
         self._hierarchy: Dict[str, Dict] = {}
         self._existing_hierarchy: DataFrame = pd.DataFrame()
