@@ -3,6 +3,7 @@ import shutil
 import time
 from pathlib import Path
 from tempfile import TemporaryDirectory
+from typing import Optional
 
 from cognite.client import CogniteClient
 from cognite.experimental import CogniteClient as ExperimentalClient
@@ -40,22 +41,29 @@ def zip_and_upload(client: CogniteClient, code_path: Path, file_name: str, data_
         return file.id
 
 
-def does_function_exist(client: ExperimentalClient, function_name: str) -> bool:
-    return bool(client.functions.retrieve(external_id=function_name))
+def does_function_exist(
+    client: ExperimentalClient, function_name: Optional[str] = None, function_id: Optional[int] = None
+) -> bool:
+    assert function_name is not None or function_id is not None
+    if function_id:
+        return bool(client.functions.retrieve(id=function_id))
+    if function_name:
+        return bool(client.functions.retrieve(external_id=function_name))
+    return False
 
 
-def await_function_deployment(client: ExperimentalClient, function_name: str, max_wait: int) -> bool:
+def await_function_deployment(client: ExperimentalClient, function_id: int, max_wait: int) -> bool:
     t_end = time.time() + max_wait
     while time.time() < t_end:
-        function = client.functions.retrieve(external_id=function_name)
+        function = client.functions.retrieve(id=function_id)
         if function is not None:
-            print(f"Function status {function.status} - Function id {function.id}")
+            print(f"Function status {function.status} - Function id {function_id}")
             if function.status == "Ready":
                 return True
             if function.status == "Failed":
                 return False
         else:
-            print(f"API returns None for {function_name}")
+            print(f"API returns None for Function id {function_id}")
         time.sleep(5.0)
 
     return False
