@@ -1,7 +1,7 @@
 import os
 import time
 from pathlib import Path
-from typing import Dict, Iterator, Union
+from typing import Dict, Iterator, Optional, Union
 
 from cognite.client.exceptions import CogniteAPIError
 from cognite.experimental import CogniteClient
@@ -26,14 +26,21 @@ def format_secret_names(secrets: Dict[str, str]) -> Dict[str, str]:
 
 def delete_function_if_exists(
     client: CogniteClient,
-    function_name: str,
+    function_name: Optional[str] = None,
+    function_id: Optional[int] = None,
 ):
-    if cdf.does_function_exist(client, function_name):
+    assert function_name is not None or function_id is not None
+
+    if cdf.does_function_exist(client, function_name, function_id):
         print(
-            f"Function with name {function_name} already exists for {client.config.project}, will delete it.",
+            f"Function with name/id {function_name if function_id is None else function_id} "
+            + f"already exists for {client.config.project}, will delete it.",
             flush=True,
         )
-        client.functions.delete(external_id=function_name)
+        if function_id:
+            client.functions.delete(id=function_id)
+        if function_name:
+            client.functions.delete(external_id=function_name)
 
 
 def deploy_function(
@@ -55,6 +62,7 @@ def deploy_function(
     x = 0
     y = 0
     while x < 3:
+        function = None
         try:
             function = client.functions.create(
                 name=function_name,
@@ -64,11 +72,13 @@ def deploy_function(
                 api_key=client._config.api_key if not oidc else None,
                 owner=owner,
             )
-            success = cdf.await_function_deployment(client, function_name, 900)
+            success = cdf.await_function_deployment(client, function, 900)
             if not success:
                 raise TimeoutError(f"Deployment of function with external id {function_name} timed out or failed.")
             print(
-                f"Function {function_name} (id: {function.id}) successfully created in project {client.config.project}."
+                f"Function {function_name} (id: {function.id}) "
+                + f"successfully created in project {client.config.project}.",
+                flush=True,
             )
             x = 3
         except (
@@ -79,10 +89,13 @@ def deploy_function(
             ConnectionError,
             AttributeError,
         ) as e:
-            print(e)
+            print(e, flush=True)
             if isinstance(e, CogniteAPIError) and e.code == 400:
                 time.sleep(1)
-                delete_function_if_exists(client, function_name)
+                if function is not None:
+                    delete_function_if_exists(client, function_id=function.id)
+                else:
+                    delete_function_if_exists(client, function_name=function_name)
                 y += 1
                 if y > 30:
                     x += 1
@@ -97,7 +110,7 @@ def delete_function(client: CogniteClient, external_id: str):
     if cdf.does_function_exist(client, external_id):
         print(f"Deleting function named {external_id} ...", flush=True)
         client.functions.delete(external_id=external_id)
-        print(f"Function {external_id} successfully deleted from project {client.config.project}.")
+        print(f"Function {external_id} successfully deleted from project {client.config.project}.", flush=True)
 
 
 def list_dangling_function(
